#!/bin/sh
# Fix some path in scripts and then install
if [ $# != 4 ] ; then
	echo '*******' install-fix.sh file destfile /usr/sbin /usr/lib/vserver
	exit 1
else
	DEST=$2
	if [ -d $DEST ] ; then
		DEST=$2/`basename $1`
	fi
	#echo $DEST
	cat $1 \
		| sed s.USR_SBIN=/usr/sbin.USR_SBIN=$3. \
		| sed s.USR_LIB_VSERVER=/usr/lib/vserver.USR_LIB_VSERVER=$4. \
		| (dd of=$DEST 2>/dev/null)
	chmod 755 $DEST
fi

